ElaborateEvaluation

Struct ElaborateEvaluation 

pub struct ElaborateEvaluation;
Selects the branch with the highest total token usage.

Prefer this strategy when depth and thoroughness are the priority and you want the most detailed response among the branches.