pub fn parse_config_file(path: &Path) -> Result<AgentConfig, ConfigError>Expand description
Parse a config file, detecting format from the file extension.
Supported extensions: .toml, .json, .yaml, .yml
pub fn parse_config_file(path: &Path) -> Result<AgentConfig, ConfigError>Parse a config file, detecting format from the file extension.
Supported extensions: .toml, .json, .yaml, .yml