Module recorder

Module recorder 

Structs

SessionRecorder
Records every AgentEvent into a structured tree of Sessions and LoopRecords.
SessionRecorderConfig
Configuration for SessionRecorder.

Type Aliases

AfterTaskFn
Called when a session is finalized (via flush() or explicit close).
BeforeTaskFn
Called when a new session is first created (first AgentStart with a new session_id).