Module storage

Module storage 

Structs

FileSystemSessionStore
Filesystem-backed SessionStore with advisory locking and atomic writes.

Traits

SessionStore
Async pluggable persistence backend for sessions.

Functions

delete_session
Delete {dir}/{session_id}.json.
list_session_ids
List all session IDs in dir, sorted by file modification time (newest first).
load_session
Load a session from {dir}/{session_id}.json.
load_sessions_for_agent
Load all sessions in dir that belong to agent_id.
save_session
Save a session to {dir}/{session_id}.json, creating dir if necessary.